==> haskell-fdo-notify-0.3.1-914-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-KyPSkengucuJvbxhh9nwCg
key:                  fdo-notify-0.3.1-KyPSkengucuJvbxhh9nwCg
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  2760e67db51bd3dc0a2764939a05ebfb
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-KyPSkengucuJvbxhh9nwCg
depends:
    base-4.18.2.1 containers-0.6.7 dbus-1.3.3-INvnWTkkmrECqNpDSboXTA

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-916-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-CtWKPECq8DDCgWKHRge3dl
key:                  fdo-notify-0.3.1-CtWKPECq8DDCgWKHRge3dl
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  5c2582e41aaba8300224e21e86cfbe4c
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-CtWKPECq8DDCgWKHRge3dl
depends:
    base-4.18.2.1 containers-0.6.7 dbus-1.3.3-G1Ov6W8p6PCE1zpW2NkSy4

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
